@@ -9,9 +9,9 @@ def test_user_identified():
     user2 = UserIdentified.by_user_id("user_id")
     user3 = UserIdentified.by_email("email")
 
-    assert (user1.format_identification() == {"email": "email", "userId": "user_id"})
-    assert (user2.format_identification() == {"userId": "user_id"})
-    assert (user3.format_identification() == {"email": "email"})
+    assert user1.format_identification() == {"email": "email", "userId": "user_id"}
+    assert user2.format_identification() == {"userId": "user_id"}
+    assert user3.format_identification() == {"email": "email"}
 
     with pytest.raises(JournyException):
         UserIdentified("", "")
